==> cohesity_management_sdk-1.6.10.tar.gz: cohesity_management_sdk-1.6.10/cohesity_management_sdk/models/privilege_id_enum.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Cohesity Inc.

class PrivilegeIdEnum(object):

    """Implementation of the 'PrivilegeId' enum.

    Specifies unique id for a privilege. This number must be unique when
    creating a new privilege.
    Type for unique privilege Id values.
    All below enum values specify a value for all uniquely defined
    privileges in Cohesity.

    Attributes:
        KPRINCIPALVIEW: TODO: type description here.
        KPRINCIPALMODIFY: TODO: type description here.
        KAPPLAUNCH: TODO: type description here.
        KAPPSMANAGEMENT: TODO: type description here.
        KORGANIZATIONVIEW: TODO: type description here.
        KORGANIZATIONMODIFY: TODO: type description here.
        KORGANIZATIONIMPERSONATE: TODO: type description here.
        KCLONEVIEW: TODO: type description here.
        KCLONEMODIFY: TODO: type description here.
        KCLUSTERVIEW: TODO: type description here.
        KCLUSTERMODIFY: TODO: type description here.
        KCLUSTERCREATE: TODO: type description here.
        KCLUSTERSUPPORT: TODO: type description here.
        KCLUSTERUPGRADE: TODO: type description here.
        KCLUSTERREMOTEVIEW: TODO: type description here.
        KCLUSTERREMOTEMODIFY: TODO: type description here.
        KCLUSTEREXTERNALTARGETVIEW: TODO: type description here.
        KCLUSTEREXTERNALTARGETMODIFY: TODO: type description here.
        KCLUSTERAUDIT: TODO: type description here.
        KALERTVIEW: TODO: type description here.
        KALERTMODIFY: TODO: type description here.
        KVLANVIEW: TODO: type description here.
        KVLANMODIFY: TODO: type description here.
        KHYBRIDEXTENDERVIEW: TODO: type description here.
        KHYBRIDEXTENDERDOWNLOAD: TODO: type description here.
        KADLDAPVIEW: TODO: type description here.
        KADLDAPMODIFY: TODO: type description here.
        KSCHEDULERVIEW: TODO: type description here.
        KSCHEDULERMODIFY: TODO: type description here.
        KPROTECTIONVIEW: TODO: type description here.
        KPROTECTIONMODIFY: TODO: type description here.
        KPROTECTIONJOBOPERATE: TODO: type description here.
        KPROTECTIONSOURCEMODIFY: TODO: type description here.
        KPROTECTIONPOLICYVIEW: TODO: type description here.
        KPROTECTIONPOLICYMODIFY: TODO: type description here.
        KRESTOREVIEW: TODO: type description here.
        KRESTOREMODIFY: TODO: type description here.
        KRESTOREDOWNLOAD: TODO: type description here.
        KREMOTERESTORE: TODO: type description here.
        KSTORAGEVIEW: TODO: type description here.
        KSTORAGEMODIFY: TODO: type description here.
        KSTORAGEDOMAINVIEW: TODO: type description here.
        KSTORAGEDOMAINMODIFY: TODO: type description here.
        KANALYTICSVIEW: TODO: type description here.
        KANALYTICSMODIFY: TODO: type description here.
        KREPORTSVIEW: TODO: type description here.
        KMCMMODIFY: TODO: type description here.
        KDATASECURITY: TODO: type description here.
        KSMBBACKUP: TODO: type description here.
        KSMBRESTORE: TODO: type description here.
        KSMBTAKEOWNERSHIP: TODO: type description here.
        KSMBAUDITING: TODO: type description here.
        KMCMUNREGISTER: TODO: type description here.
        KMCMUPGRADE: TODO: type description here.
        KMCMMODIFYSUPERADMIN: TODO: type description here.
        KMCMVIEWSUPERADMIN: TODO: type description here.
        KMCMMODIFYCOHESITYADMIN: TODO: type description here.
        KMCMVIEWCOHESITYADMIN: TODO: type description here.
        KOBJECTSEARCH: TODO: type description here.
        KFILEDATALOCKEXPIRYTIMEDECREASE: TODO: type description here.

    """

    KPRINCIPALVIEW = 'kPrincipalView'

    KPRINCIPALMODIFY = 'kPrincipalModify'

    KAPPLAUNCH = 'kAppLaunch'

    KAPPSMANAGEMENT = 'kAppsManagement'

    KORGANIZATIONVIEW = 'kOrganizationView'

    KORGANIZATIONMODIFY = 'kOrganizationModify'

    KORGANIZATIONIMPERSONATE = 'kOrganizationImpersonate'

    KCLONEVIEW = 'kCloneView'

    KCLONEMODIFY = 'kCloneModify'

    KCLUSTERVIEW = 'kClusterView'

    KCLUSTERMODIFY = 'kClusterModify'

    KCLUSTERCREATE = 'kClusterCreate'

    KCLUSTERSUPPORT = 'kClusterSupport'

    KCLUSTERUPGRADE = 'kClusterUpgrade'

    KCLUSTERREMOTEVIEW = 'kClusterRemoteView'

    KCLUSTERREMOTEMODIFY = 'kClusterRemoteModify'

    KCLUSTEREXTERNALTARGETVIEW = 'kClusterExternalTargetView'

    KCLUSTEREXTERNALTARGETMODIFY = 'kClusterExternalTargetModify'

    KCLUSTERAUDIT = 'kClusterAudit'

    KALERTVIEW = 'kAlertView'

    KALERTMODIFY = 'kAlertModify'

    KVLANVIEW = 'kVlanView'

    KVLANMODIFY = 'kVlanModify'

    KHYBRIDEXTENDERVIEW = 'kHybridExtenderView'

    KHYBRIDEXTENDERDOWNLOAD = 'kHybridExtenderDownload'

    KADLDAPVIEW = 'kAdLdapView'

    KADLDAPMODIFY = 'kAdLdapModify'

    KSCHEDULERVIEW = 'kSchedulerView'

    KSCHEDULERMODIFY = 'kSchedulerModify'

    KPROTECTIONVIEW = 'kProtectionView'

    KPROTECTIONMODIFY = 'kProtectionModify'

    KPROTECTIONJOBOPERATE = 'kProtectionJobOperate'

    KPROTECTIONSOURCEMODIFY = 'kProtectionSourceModify'

    KPROTECTIONPOLICYVIEW = 'kProtectionPolicyView'

    KPROTECTIONPOLICYMODIFY = 'kProtectionPolicyModify'

    KRESTOREVIEW = 'kRestoreView'

    KRESTOREMODIFY = 'kRestoreModify'

    KRESTOREDOWNLOAD = 'kRestoreDownload'

    KREMOTERESTORE = 'kRemoteRestore'

    KSTORAGEVIEW = 'kStorageView'

    KSTORAGEMODIFY = 'kStorageModify'

    KSTORAGEDOMAINVIEW = 'kStorageDomainView'

    KSTORAGEDOMAINMODIFY = 'kStorageDomainModify'

    KANALYTICSVIEW = 'kAnalyticsView'

    KANALYTICSMODIFY = 'kAnalyticsModify'

    KREPORTSVIEW = 'kReportsView'

    KMCMMODIFY = 'kMcmModify'

    KDATASECURITY = 'kDataSecurity'

    KSMBBACKUP = 'kSmbBackup'

    KSMBRESTORE = 'kSmbRestore'

    KSMBTAKEOWNERSHIP = 'kSmbTakeOwnership'

    KSMBAUDITING = 'kSmbAuditing'

    KMCMUNREGISTER = 'kMcmUnregister'

    KMCMUPGRADE = 'kMcmUpgrade'

    KMCMMODIFYSUPERADMIN = 'kMcmModifySuperAdmin'

    KMCMVIEWSUPERADMIN = 'kMcmViewSuperAdmin'

    KMCMMODIFYCOHESITYADMIN = 'kMcmModifyCohesityAdmin'

    KMCMVIEWCOHESITYADMIN = 'kMcmViewCohesityAdmin'

    KOBJECTSEARCH = 'kObjectSearch'

    KFILEDATALOCKEXPIRYTIMEDECREASE = 'kFileDatalockExpiryTimeDecrease'

==> cohesity_management_sdk-1.9.1.tar.gz: cohesity_management_sdk-1.9.1/cohesity_management_sdk/models/privilege_id_enum.py <==
# -*- coding: utf-8 -*-
# Copyright 2023 Cohesity Inc.

class PrivilegeIdEnum(object):

    """Implementation of the 'PrivilegeId' enum.
    Specifies unique id for a privilege. This number must be unique when
    creating a new privilege. Type for unique privilege Id values. All below
    enum values specify a value for all uniquely defined privileges in
    Cohesity.


    Attributes:
        KPRINCIPALVIEW: TODO: type description here.
        KPRINCIPALMODIFY: TODO: type description here.
        KAPPLAUNCH: TODO: type description here.
        KAPPSMANAGEMENT: TODO: type description here.
        KORGANIZATIONVIEW: TODO: type description here.
        KORGANIZATIONMODIFY: TODO: type description here.
        KORGANIZATIONIMPERSONATE: TODO: type description here.
        KCLONEVIEW: TODO: type description here.
        KCLONEMODIFY: TODO: type description here.
        KCLUSTERVIEW: TODO: type description here.
        KCLUSTERMODIFY: TODO: type description here.
        KCLUSTERCREATE: TODO: type description here.
        KCLUSTERSUPPORT: TODO: type description here.
        KCLUSTERUPGRADE: TODO: type description here.
        KCLUSTERREMOTEVIEW: TODO: type description here.
        KCLUSTERREMOTEMODIFY: TODO: type description here.
        KCLUSTEREXTERNALTARGETVIEW: TODO: type description here.
        KCLUSTEREXTERNALTARGETMODIFY: TODO: type description here.
        KCLUSTERAUDIT: TODO: type description here.
        KALERTVIEW: TODO: type description here.
        KALERTMODIFY: TODO: type description here.
        KVLANVIEW: TODO: type description here.
        KVLANMODIFY: TODO: type description here.
        KHYBRIDEXTENDERVIEW: TODO: type description here.
        KHYBRIDEXTENDERDOWNLOAD: TODO: type description here.
        KADLDAPVIEW: TODO: type description here.
        KADLDAPMODIFY: TODO: type description here.
        KSCHEDULERVIEW: TODO: type description here.
        KSCHEDULERMODIFY: TODO: type description here.
        KPROTECTIONVIEW: TODO: type description here.
        KPROTECTIONMODIFY: TODO: type description here.
        KPROTECTIONJOBOPERATE: TODO: type description here.
        KPROTECTIONSOURCEMODIFY: TODO: type description here.
        KPROTECTIONPOLICYVIEW: TODO: type description here.
        KPROTECTIONPOLICYMODIFY: TODO: type description here.
        KRESTOREVIEW: TODO: type description here.
        KRESTOREMODIFY: TODO: type description here.
        KRESTOREDOWNLOAD: TODO: type description here.
        KREMOTERESTORE: TODO: type description here.
        KSTORAGEVIEW: TODO: type description here.
        KSTORAGEMODIFY: TODO: type description here.
        KSTORAGEDOMAINVIEW: TODO: type description here.
        KSTORAGEDOMAINMODIFY: TODO: type description here.
        KANALYTICSVIEW: TODO: type description here.
        KANALYTICSMODIFY: TODO: type description here.
        KREPORTSVIEW: TODO: type description here.
        KMCMMODIFY: TODO: type description here.
        KDATASECURITY: TODO: type description here.
        KSMBBACKUP: TODO: type description here.
        KSMBRESTORE: TODO: type description here.
        KSMBTAKEOWNERSHIP: TODO: type description here.
        KSMBAUDITING: TODO: type description here.
        KMCMUNREGISTER: TODO: type description here.
        KMCMUPGRADE: TODO: type description here.
        KMCMMODIFYSUPERADMIN: TODO: type description here.
        KMCMVIEWSUPERADMIN: TODO: type description here.
        KMCMMODIFYCOHESITYADMIN: TODO: type description here.
        KMCMVIEWCOHESITYADMIN: TODO: type description here.
        KOBJECTSEARCH: TODO: type description here.
        KFILEDATALOCKEXPIRYTIMEDECREASE: TODO: type description here.

    """

    KPRINCIPALVIEW = 'kPrincipalView'

    KPRINCIPALMODIFY = 'kPrincipalModify'

    KAPPLAUNCH = 'kAppLaunch'

    KAPPSMANAGEMENT = 'kAppsManagement'

    KORGANIZATIONVIEW = 'kOrganizationView'

    KORGANIZATIONMODIFY = 'kOrganizationModify'

    KORGANIZATIONIMPERSONATE = 'kOrganizationImpersonate'

    KCLONEVIEW = 'kCloneView'

    KCLONEMODIFY = 'kCloneModify'

    KCLUSTERVIEW = 'kClusterView'

    KCLUSTERMODIFY = 'kClusterModify'

    KCLUSTERCREATE = 'kClusterCreate'

    KCLUSTERSUPPORT = 'kClusterSupport'

    KCLUSTERUPGRADE = 'kClusterUpgrade'

    KCLUSTERREMOTEVIEW = 'kClusterRemoteView'

    KCLUSTERREMOTEMODIFY = 'kClusterRemoteModify'

    KCLUSTEREXTERNALTARGETVIEW = 'kClusterExternalTargetView'

    KCLUSTEREXTERNALTARGETMODIFY = 'kClusterExternalTargetModify'

    KCLUSTERAUDIT = 'kClusterAudit'

    KALERTVIEW = 'kAlertView'

    KALERTMODIFY = 'kAlertModify'

    KVLANVIEW = 'kVlanView'

    KVLANMODIFY = 'kVlanModify'

    KHYBRIDEXTENDERVIEW = 'kHybridExtenderView'

    KHYBRIDEXTENDERDOWNLOAD = 'kHybridExtenderDownload'

    KADLDAPVIEW = 'kAdLdapView'

    KADLDAPMODIFY = 'kAdLdapModify'

    KSCHEDULERVIEW = 'kSchedulerView'

    KSCHEDULERMODIFY = 'kSchedulerModify'

    KPROTECTIONVIEW = 'kProtectionView'

    KPROTECTIONMODIFY = 'kProtectionModify'

    KPROTECTIONJOBOPERATE = 'kProtectionJobOperate'

    KPROTECTIONSOURCEMODIFY = 'kProtectionSourceModify'

    KPROTECTIONPOLICYVIEW = 'kProtectionPolicyView'

    KPROTECTIONPOLICYMODIFY = 'kProtectionPolicyModify'

    KRESTOREVIEW = 'kRestoreView'

    KRESTOREMODIFY = 'kRestoreModify'

    KRESTOREDOWNLOAD = 'kRestoreDownload'

    KREMOTERESTORE = 'kRemoteRestore'

    KSTORAGEVIEW = 'kStorageView'

    KSTORAGEMODIFY = 'kStorageModify'

    KSTORAGEDOMAINVIEW = 'kStorageDomainView'

    KSTORAGEDOMAINMODIFY = 'kStorageDomainModify'

    KANALYTICSVIEW = 'kAnalyticsView'

    KANALYTICSMODIFY = 'kAnalyticsModify'

    KREPORTSVIEW = 'kReportsView'

    KMCMMODIFY = 'kMcmModify'

    KDATASECURITY = 'kDataSecurity'

    KSMBBACKUP = 'kSmbBackup'

    KSMBRESTORE = 'kSmbRestore'

    KSMBTAKEOWNERSHIP = 'kSmbTakeOwnership'

    KSMBAUDITING = 'kSmbAuditing'

    KMCMUNREGISTER = 'kMcmUnregister'

    KMCMUPGRADE = 'kMcmUpgrade'

    KMCMMODIFYSUPERADMIN = 'kMcmModifySuperAdmin'

    KMCMVIEWSUPERADMIN = 'kMcmViewSuperAdmin'

    KMCMMODIFYCOHESITYADMIN = 'kMcmModifyCohesityAdmin'

    KMCMVIEWCOHESITYADMIN = 'kMcmViewCohesityAdmin'

    KOBJECTSEARCH = 'kObjectSearch'

    KFILEDATALOCKEXPIRYTIMEDECREASE = 'kFileDatalockExpiryTimeDecrease'
